'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Response = undefined;

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Standard response model, used for building the shared response object for all statuses.
 */

var Response = function () {

  /**
   * Builds up the standard structure object for fail, success and error.
   *
   * @param  {string}  status  - Should be either 'error', 'success' or 'fail'.
   * @param  {integer}  httpStatus  - HTTP status code to be sent in the structure object, used for
   *                                  mapping responses in API Gateway.
   * @param  {object}  data  - Used to send main data in the response, optional for error responses.
   * @param  {string}  message - Used only in error responses. This should be the error message.
   * @return  {object}  - The current object.
   */

  function Response(status, httpStatus, data, message) {
    (0, _classCallCheck3.default)(this, Response);

    var messageToAdd = message || '';

    this.structure = {};
    this.structure.status = status;
    this.structure.httpStatus = httpStatus;

    if (data) {
      this.structure.data = data;
    }

    if (status === 'error') {
      this.structure.message = messageToAdd;
    }

    return this;
  }

  /**
   * Gets the structure object built in the constructor.
   *
   * @return  {object}  - Response structure object.
   */


  (0, _createClass3.default)(Response, [{
    key: 'getStructure',
    value: function getStructure() {
      return this.structure;
    }

    /**
     * Gets the JSON stringified structure object.
     *
     * @return  {string}  - JSON stringified response structure object.
     */

  }, {
    key: 'getStringifiedStructure',
    value: function getStringifiedStructure() {
      return (0, _stringify2.default)(this.structure);
    }
  }]);
  return Response;
}();

exports.Response = Response;