'use strict';

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _chai = require('chai');

var _chai2 = _interopRequireDefault(_chai);

var _response = require('../models/response');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var expect = _chai2.default.expect; /* eslint-env node, mocha */


describe('Response Model', function () {
  var response1 = new _response.Response('success', 202);
  var response2 = new _response.Response('success', 200, { foo: 'bar' });
  var response3 = new _response.Response('error', 400, null, 'Invalid params');
  var response4 = new _response.Response('error', 400);
  describe('Constructor', function () {
    it('Adds the status and httpStatus to the structure when they are both passed in', function () {
      var structure = response1.structure;
      expect(structure).to.be.an('object');
      expect(structure.status).to.equal('success');
      expect(structure.httpStatus).to.equal(202);
    });

    it('Adds the data object to the structure when a data object is specified', function () {
      var structure = response2.structure;
      expect(structure).to.be.an('object');
      expect(structure.data).to.be.an('object');
      expect(structure.data.foo).to.equal('bar');
    });

    it('Does not add the data object to the structure when a data object is not specified', function () {
      var structure = response1.structure;
      expect(structure).to.be.an('object');
      expect(structure.data).to.equal(undefined);
    });

    it('Adds a message when one is passed in and when the status is "error"', function () {
      var structure = response3.structure;
      expect(structure).to.be.an('object');
      expect(structure.message).to.be.a('string');
      expect(structure.message).to.equal('Invalid params');
    });

    it('Adds an empty message when the status is "error" and no message is specified', function () {
      var structure = response4.structure;
      expect(structure).to.be.an('object');
      expect(structure.message).to.be.a('string');
      expect(structure.message).to.equal('');
    });

    it('Does not add a message when the status is not "error"', function () {
      var structure = response1.structure;
      expect(structure).to.be.an('object');
      expect(structure.message).to.equal(undefined);
    });
  });

  describe('getStructure', function () {
    it('Returns the structure object', function () {
      var structure = response2.structure;
      expect(response2.getStructure()).to.equal(structure);
    });
  });

  describe('getStringifiedStructure', function () {
    it('Returns the structure object JSON stringified', function () {
      var structure = response2.structure;
      expect(response2.getStringifiedStructure()).to.equal((0, _stringify2.default)(structure));
    });
  });
});